@@ -35,7 +35,7 @@ class Base(Controller):
         self.app.args.print_help()
 
     @ex(
-        # TODO: implement `--home` for setting up home address 
+        # TODO: implement `--home` for setting up home address
         help='AWS Security Groups helper functions',
         arguments=[
             (['action'],{
@@ -246,6 +246,34 @@ class Base(Controller):
                 os.system('dt sg update')
                 os.system(f'ssh {target}')
 
+    @ex(
+        help='Viz',
+        arguments = [
+            (['images'], {
+                'help' : 'Location of target images',
+                'action' : "store"
+            }),
+            (['labels'], {
+                'help' : 'Location of target labels',
+                "action" : 'store'
+            }),
+            (['adapted'], {
+                'help' : 'Location of domain adapted images',
+                "action" : "store"
+            })
+            #     'action' : "store",
+            #     "images" : '/efs/public_data/gta5/images',
+            #     "labels" : '/efs/public_data/gta5/labels',
+            #     "adapted" : '/efs/public_data/images'
+            # })
+        ]
+    )
+    def viz(self):
+        args = self.app.pargs
+        print(args.images)
+        from ..ext.firelit import create_viz
+        create_viz(args.images, args.labels, args.adapted)
+
 
     @ex(
         help='Operations with config.',
